ConvexPolytope

Struct ConvexPolytope 

pub struct ConvexPolytope<const N: usize, const MAX_VERTICES: usize = 64> { /* private fields */ }
A faceted solid defined by the convex hull of a set of points.

ConvexPolytope stores the given point set without any modification. Therefore, it can be constructed quickly. The implicit convex hull is formed by SupportMapping during intersection tests of Convex(ConvexPolytope) with other Convex(_) types.

Every vertex in the convex hull is an elements of vertices. vertices may also include duplicate, collinear, coplanar, and/or interior points. They are exactly the points given at construction.

Examples

Construction and basic methods:

use approxim::assert_relative_eq;
use hoomd_geometry::{BoundingSphereRadius, shape::ConvexPolyhedron};

let tetrahedron = ConvexPolyhedron::with_vertices([
    [1.0, 1.0, 1.0].into(),
    [1.0, -1.0, -1.0].into(),
    [-1.0, 1.0, -1.0].into(),
    [-1.0, -1.0, 1.0].into(),
])?;

let bounding_radius = tetrahedron.bounding_sphere_radius();

assert_relative_eq!(bounding_radius.get(), 3.0_f64.sqrt());

Intersection tests:

use hoomd_geometry::{Convex, IntersectsAt, shape::ConvexPolygon};
use hoomd_vector::{Angle, Cartesian};
use std::f64::consts::PI;

let rectangle = ConvexPolygon::with_vertices([
    [-2.0, -1.0].into(),
    [2.0, -1.0].into(),
    [2.0, 1.0].into(),
    [-2.0, 1.0].into(),
])?;
let rectangle = Convex(rectangle);

assert!(!rectangle.intersects_at(
    &rectangle,
    &[0.0, 2.1].into(),
    &Angle::default()
));
assert!(rectangle.intersects_at(
    &rectangle,
    &[0.0, 2.1].into(),
    &Angle::from(PI / 2.0)
));

Implementations

Source

impl<const MAX_VERTICES: usize> ConvexPolytope<2, MAX_VERTICES>

pub fn regular(n: usize) -> ConvexPolytope<2, MAX_VERTICES>

Create a regular n-gon with n vertices and circumradius 0.5.

Example
use hoomd_geometry::shape::ConvexPolygon;

let equilateral_triangle = ConvexPolygon::regular(3);
Source

impl<const N: usize, const MAX_VERTICES: usize> ConvexPolytope<N, MAX_VERTICES>

pub fn with_vertices<I>( vertices: I, ) -> Result<ConvexPolytope<N, MAX_VERTICES>, Error>
where I: IntoIterator<Item = Cartesian<N>>,

Create an N-polytope with the given vertices.

Example
use hoomd_geometry::shape::ConvexPolytope;

let equilateral_triangle = ConvexPolytope::<2>::with_vertices([
    [1.0, 0.0].into(),
    [0.5, f64::sqrt(3.0) / 2.0].into(),
    [-0.5, f64::sqrt(3.0) / 2.0].into(),
])?;
Errors

Error::DegeneratePolytope when no vertices are provided.

pub fn vertices(&self) -> &[Cartesian<N>]

The vertices of the shape.