ConvexSurfaceMesh2d

Struct ConvexSurfaceMesh2d 

pub struct ConvexSurfaceMesh2d { /* private fields */ }
The vertices and edges that make up a convex polygon.

ConvexPolytope::<2> and ConvexSurfaceMesh2d can both represent 2d convex polygons. The first is defined implicitly as the convex hull of a set of points. It stores the given point set without any modification, and can therefore be constructed quickly. The implicit convex hull is formed by SupportMapping during intersection tests of Convex(ConvexPolygon) with other Convex(_) types.

In contrast, ConvexSurfaceMesh2d explicitly computes the convex hull on construction. After construction, the vertices of the shape include only the points on the convex hull in a counter-clockwise order. Using this representation, ConvexSurfaceMesh2d is able to provide implementations of Volume, IsPointInside, and IntersectsAt. The native ConvexSurfaceMesh2dConvexSurfaceMesh2d intersection test is much faster than the generic Convex(ConvexPolygon) intersection test.

Examples

Construction:

use hoomd_geometry::shape::ConvexSurfaceMesh2d;

let triangle = ConvexSurfaceMesh2d::from_point_set([
    [1.0, -1.0].into(),
    [-1.0, -1.0].into(),
    [0.0, 1.0].into(),
])?;

Intersection tests:

use hoomd_geometry::{Convex, IntersectsAt, shape::ConvexSurfaceMesh2d};
use hoomd_vector::{Angle, Cartesian};
use std::f64::consts::PI;

let rectangle = ConvexSurfaceMesh2d::from_point_set([
    [-2.0, -1.0].into(),
    [2.0, -1.0].into(),
    [2.0, 1.0].into(),
    [-2.0, 1.0].into(),
])?;

assert!(!rectangle.intersects_at(
    &rectangle,
    &[0.0, 2.1].into(),
    &Angle::default()
));
assert!(rectangle.intersects_at(
    &rectangle,
    &[0.0, 2.1].into(),
    &Angle::from(PI / 2.0)
));

Implementations

Source

impl ConvexSurfaceMesh2d

pub fn from_point_set<I>(points: I) -> Result<Self, Error>
where I: IntoIterator<Item = Cartesian<2>>,

Create an convex surface mesh from the convex hull of the given set of points.

The resulting shape contains a subset of the given points, including only the non-degenerate points on the convex hull. The result’s vertices are arranged in a counter-clockwise order.

Errors
Example
use hoomd_geometry::shape::ConvexSurfaceMesh2d;

let equilateral_triangle = ConvexSurfaceMesh2d::from_point_set([
    [1.0, 0.0].into(),
    [0.5, f64::sqrt(3.0) / 2.0].into(),
    [-0.5, f64::sqrt(3.0) / 2.0].into(),
])?;
pub fn construct_convex_hull( points: Vec<Cartesian<2>>, ) -> Result<Vec<Cartesian<2>>, Error>

Compute the convex hull of points in two dimensions.

The resulting vector contains a subset of the given points, including only the non-degenerate points on the convex hull. The output vertices are arranged in a counter-clockwise order.

Errors

Returns Error if the input vertices do not form a convex body with 3 or more points.

Example
use hoomd_geometry::shape::ConvexSurfaceMesh2d;

let points = vec![
    [1.0, 0.0].into(),
    [0.5, f64::sqrt(3.0) / 2.0].into(),
    [-0.5, f64::sqrt(3.0) / 2.0].into(),
];

let hull_vertices = ConvexSurfaceMesh2d::construct_convex_hull(points)?;
pub fn vertices(&self) -> &[Cartesian<2>]

The vertices of the convex polygon in counter-clockwise order.