HyperbolicConvexPolytope

Struct HyperbolicConvexPolytope 

pub struct HyperbolicConvexPolytope<const N: usize> { /* private fields */ }
A faceted hyperbolic solid defined by the convex hull of its vertices.

Examples

Construction and basic methods:

use hoomd_geometry::{
    BoundingSphereRadius, shape::HyperbolicConvexPolytope,
};

let hyperbolic_square = HyperbolicConvexPolytope::<3>::regular(4, 0.5);

let bounding_radius = hyperbolic_square.bounding_sphere_radius();

assert_eq!(bounding_radius.get(), 0.5);

Overlap check:

use hoomd_geometry::{IntersectsAtGlobal, shape::HyperbolicConvexPolytope};
use hoomd_manifold::Hyperbolic;
use hoomd_vector::Angle;

let square = HyperbolicConvexPolytope::<3>::regular(4, 0.5);
assert!(square.intersects_at_global(
    &square,
    &Hyperbolic::<3>::default(),
    &Angle::default(),
    &Hyperbolic::<3>::from_polar_coordinates(0.49, 2.3),
    &Angle::from(0.4)
));

assert!(!square.intersects_at_global(
    &square,
    &Hyperbolic::<3>::default(),
    &Angle::default(),
    &Hyperbolic::<3>::from_polar_coordinates(3.0, 2.3),
    &Angle::from(0.2)
));

Implementations

Source

impl<const N: usize> HyperbolicConvexPolytope<N>

pub fn vertices(&self) -> &[Hyperbolic<N>]

Get the vertices of the shape.

Source

impl HyperbolicConvexPolytope<3>

pub fn regular(n: usize, circumradius: f64) -> HyperbolicConvexPolytope<3>

Create a regular n-gon with n vertices and a given circumradius in hyperbolic space.

pub fn edge_distance(&self, phi: f64) -> f64

Calculate the distance between the center of a HyperbolicConvexPolytope<3> centered at the origin and the edge at angle phi. The calculation works by computing the intersection of the the hyperboloid with a plane passing through the origin and the two adjacent vertices of the polygon.

Example
use approxim::assert_relative_eq;
use hoomd_geometry::shape::HyperbolicConvexPolytope;
use std::f64::consts::PI;

let bounding_radius = 0.5;
let hyperbolic_square =
    HyperbolicConvexPolytope::<3>::regular(4, bounding_radius);

// calculation using hyperbolic trigonometry
let pi_fourths_distance =
    (((PI / 4.0).cos()) * (bounding_radius.tanh())).atanh();

let edge_distance = hyperbolic_square.edge_distance(PI / 4.0);

assert_relative_eq!(pi_fourths_distance, edge_distance);