Hypercuboid

Struct Hypercuboid 

pub struct Hypercuboid<const N: usize> {
    pub edge_lengths: [PositiveReal; N],
}
A shape with with all perpendicular angles made from axis-aligned edges.

A Hypercuboid is the N-dimensional analog of a rectangle, and is defined by its edge lengths. Each perpendicular edge of the cuboid is aligned along the corresponding Cartesian axis. The hypercuboid is placed with its centroid at the origin.

Example

Construction and basic methods:

use hoomd_geometry::{Volume, shape::Hypercuboid};

let unit_cube = Hypercuboid {
    edge_lengths: [1.0.try_into()?; 3],
};
assert_eq!(unit_cube.volume(), 1.0);

let min_extents = unit_cube.minimal_extents();
let max_extents = unit_cube.maximal_extents();
assert_eq!(min_extents, [-0.5; 3]);
assert_eq!(max_extents, [0.5; 3]);

let rectangular_prism = Hypercuboid {
    edge_lengths: [1.0.try_into()?, 1.0.try_into()?, 9.0.try_into()?],
};

assert_eq!(rectangular_prism.volume(), 9.0);

Perform a fast AABB intersection tests:

use hoomd_geometry::shape::Hypercuboid;

let unit_cube = Hypercuboid {
    edge_lengths: [1.0.try_into()?; 3],
};
let rectangular_prism = Hypercuboid {
    edge_lengths: [1.0.try_into()?, 1.0.try_into()?, 9.0.try_into()?],
};

assert!(unit_cube.intersects_aligned(&rectangular_prism, &[1.0; 3].into()));
assert!(
    !unit_cube.intersects_aligned(&rectangular_prism, &[1.1; 3].into())
);

Wrap with Convex to check intersections of oriented cuboids:

use hoomd_geometry::{Convex, IntersectsAt, shape::Rectangle};
use hoomd_vector::Angle;
use std::f64::consts::PI;

let square = Convex(Rectangle {
    edge_lengths: [1.0.try_into()?; 2],
});

assert!(!square.intersects_at(
    &square,
    &[1.1, 0.0].into(),
    &Angle::default()
));
assert!(square.intersects_at(
    &square,
    &[1.1, 0.0].into(),
    &Angle::from(PI / 4.0)
));

Fields

edge_lengths: [PositiveReal; N]

The lengths of each edge of the cuboid.

Implementations

Source

impl Hypercuboid<3>

pub fn a(&self) -> PositiveReal

Length of the Hypercuboid edge along the x axis

pub fn b(&self) -> PositiveReal

Length of the Hypercuboid edge along the y axis

pub fn c(&self) -> PositiveReal

Length of the Hypercuboid edge along the z axis

Source

impl<const N: usize> Hypercuboid<N>

pub fn with_equal_edges(l: PositiveReal) -> Self

Construct a cuboid with all edge lengths equal.

Example
use hoomd_geometry::shape::Rectangle;

let square = Rectangle::with_equal_edges(10.0.try_into()?);
pub fn intersects_aligned( &self, other: &Hypercuboid<N>, v_ij: &Cartesian<N>, ) -> bool

Test for intersections between two axis-aligned cuboids.

This test is much faster than a general oriented cuboid (OBB) intersection, which can be achieved by wrapping with the Convex newtype.

Example
use hoomd_geometry::shape::Hypercuboid;

let unit_cube = Hypercuboid {
    edge_lengths: [1.0.try_into()?; 3],
};
let rectangular_prism = Hypercuboid {
    edge_lengths: [1.0.try_into()?, 1.0.try_into()?, 9.0.try_into()?],
};

assert!(unit_cube.intersects_aligned(&rectangular_prism, &[1.0; 3].into()));
assert!(
    !unit_cube.intersects_aligned(&rectangular_prism, &[1.1; 3].into())
);
Source

impl<const N: usize> Hypercuboid<N>

pub fn maximal_extents(&self) -> [f64; N]

Determine the maximal extents of the cuboid along each Cartesian axis.

Example
use hoomd_geometry::shape::Hypercuboid;

let unit_cube = Hypercuboid {
    edge_lengths: [1.0.try_into()?; 3],
};

let max_extents = unit_cube.maximal_extents();
assert_eq!(max_extents, [0.5; 3]);
pub fn minimal_extents(&self) -> [f64; N]

Determine the minimal extents of the cuboid along each Cartesian axis.

Example
use hoomd_geometry::shape::Hypercuboid;

let unit_cube = Hypercuboid {
    edge_lengths: [1.0.try_into()?; 3],
};

let min_extents = unit_cube.minimal_extents();
assert_eq!(min_extents, [-0.5; 3]);
Source

impl Hypercuboid<2>

pub fn to_gsd_box(&self) -> [f64; 6]

Represent the shape in the GSD box format.

Example
use hoomd_geometry::shape::Rectangle;

let rectangle = Rectangle {
    edge_lengths: [10.0.try_into()?, 15.0.try_into()?],
};

let gsd_box = rectangle.to_gsd_box();
assert_eq!(gsd_box, [10.0, 15.0, 0.0, 0.0, 0.0, 0.0]);
Source

impl Hypercuboid<3>

pub fn to_gsd_box(&self) -> [f64; 6]

Represent the shape in the GSD box format.

Example
use hoomd_geometry::shape::Cuboid;

let rectangle = Cuboid {
    edge_lengths: [10.0.try_into()?, 15.0.try_into()?, 20.0.try_into()?],
};

let gsd_box = rectangle.to_gsd_box();
assert_eq!(gsd_box, [10.0, 15.0, 20.0, 0.0, 0.0, 0.0]);