pub struct Hyperellipsoid<const N: usize> { /* private fields */ }Expand description
The geometry resulting from an Hypersphere that is scaled along the Cartesian axes.
See Ellipse and Ellipsoid for special cases in 2 and 3 dimensions.
Examples
Basic construction and methods:
use approxim::assert_relative_eq;
use hoomd_geometry::{BoundingSphereRadius, Volume, shape::Hyperellipsoid};
use std::f64::consts::PI;
let ellipse =
Hyperellipsoid::with_semi_axes([1.0.try_into()?, 2.0.try_into()?]);
let bounding_radius = ellipse.bounding_sphere_radius();
let volume = ellipse.volume();
assert_eq!(bounding_radius.get(), 2.0);
assert_relative_eq!(volume, PI * 1.0 * 2.0);
let sphere = Hyperellipsoid::with_semi_axes([
2.0.try_into()?,
2.0.try_into()?,
2.0.try_into()?,
]);
let bounding_radius = sphere.bounding_sphere_radius();
let volume = sphere.volume();
assert_eq!(bounding_radius.get(), 2.0);
assert_eq!(volume, 4.0 / 3.0 * PI * 2.0_f64.powi(3));Implementations
Sourceimpl<const N: usize> Hyperellipsoid<N>
impl<const N: usize> Hyperellipsoid<N>
Sourcepub fn with_semi_axes(semi_axes: [PositiveReal; N]) -> Self
pub fn with_semi_axes(semi_axes: [PositiveReal; N]) -> Self
Construct a new Hyperellipsoid with the given semi-axes along each Cartesian direction.
Sourcepub fn semi_axes(&self) -> &[PositiveReal; N]
pub fn semi_axes(&self) -> &[PositiveReal; N]
Get the semi axes.