Hypersphere

Struct Hypersphere 

pub struct Hypersphere<const N: usize> {
    pub radius: PositiveReal,
}
All points within a given radius from the origin.

Examples

Basic construction and methods:

use hoomd_geometry::{SupportMapping, Volume, shape::Hypersphere};
use hoomd_vector::Cartesian;
use std::f64::consts::PI;

let unit_sphere = Hypersphere::<3>::default();
let volume = unit_sphere.volume();

assert_eq!(unit_sphere.radius.get(), 1.0);
assert_eq!(volume, 4.0 * PI / 3.0);

assert_eq!(
    unit_sphere.support_mapping(&Cartesian::from([1.0; 3])),
    [1.0 / f64::sqrt(3.0); 3].into()
)

Test for intersections:

use hoomd_geometry::{IntersectsAt, shape::Hypersphere};
use hoomd_vector::{Cartesian, Versor};

let unit_sphere = Hypersphere::<3>::default();

assert!(!unit_sphere.intersects_at(
    &unit_sphere,
    &Cartesian::from([2.1, 0.0, 0.0]),
    &Versor::default()
));
assert!(unit_sphere.intersects_at(
    &unit_sphere,
    &Cartesian::from([0.0, 1.9, 0.0]),
    &Versor::default()
));

Fields

radius: PositiveReal

Radius of the sphere

Implementations

Source

impl<const N: usize> Hypersphere<N>

pub fn with_radius(radius: PositiveReal) -> Self

Create a sphere with a given positive real radius.

pub fn intersects<V>(&self, other: &Hypersphere<N>, v_ij: &V) -> bool
where V: InnerProduct,

Test whether one sphere intersects with another.

The vector v_ij points from the local origin of self to the local origin of other.