Sphero

Struct Sphero 

pub struct Sphero<S> {
    pub shape: S,
    pub rounding_radius: PositiveReal,
}
Round a shape with a given radius.

Sphero modifies a given shape by sweeping it with a hypersphere of the given radius. The resulting Sphero<S> type is a shape itself. If S implements crate::SupportMapping, then Sphero<S> can be used in IntersectsAt tests with other convex shapes. See the full list of implementations below to see what other traits Sphero<S> implements for a given S.

Example

Test if a circle overlaps with a rounded rectangle:

use hoomd_geometry::{
    Convex, IntersectsAt,
    shape::{Circle, Rectangle, Sphero},
};
use hoomd_vector::{Angle, Cartesian};
use std::f64::consts::PI;

let circle = Convex(Circle {
    radius: 0.5.try_into()?,
});
let rectangle = Rectangle {
    edge_lengths: [3.0.try_into()?, 2.0.try_into()?],
};
let rounded_rectangle = Convex(Sphero {
    shape: rectangle,
    rounding_radius: 0.5.try_into()?,
});

assert!(rounded_rectangle.intersects_at(
    &circle,
    &[2.4, 0.0].into(),
    &Angle::default()
));
assert!(!rounded_rectangle.intersects_at(
    &circle,
    &[0.0, 2.4].into(),
    &Angle::default()
));
assert!(circle.intersects_at(
    &rounded_rectangle,
    &[0.0, 2.4].into(),
    &Angle::from(PI / 2.0)
));

Fields

shape: S

The shape to round.

rounding_radius: PositiveReal

The radius of the rounding hypersphere.