Spherocylinder

Type Alias Spherocylinder 

pub type Spherocylinder = Capsule<3>;
A sphere swept along a line segment in $\mathbb{R}^3$.

Aliased Type

pub struct Spherocylinder {
    pub radius: PositiveReal,
    pub height: PositiveReal,
}

Fields

radius: PositiveReal

Radius of points that are considered enclosed in the shape.

height: PositiveReal

Length of the line segment.