Convex

Struct Convex 

pub struct Convex<S>(pub S);
A newtype that checks for intersections using xenocollide.

Use Convex to check for intersections between two convex shapes (possibly with different types).

Example

Test if a circle overlaps with a rounded rectangle:

use hoomd_geometry::{
    Convex, IntersectsAt,
    shape::{Circle, Rectangle, Sphero},
};
use hoomd_vector::{Angle, Cartesian};
use std::f64::consts::PI;

let circle = Convex(Circle {
    radius: 0.5.try_into()?,
});
let rectangle = Rectangle {
    edge_lengths: [3.0.try_into()?, 2.0.try_into()?],
};
let rounded_rectangle = Convex(Sphero {
    shape: rectangle,
    rounding_radius: 0.5.try_into()?,
});

assert!(rounded_rectangle.intersects_at(
    &circle,
    &[2.4, 0.0].into(),
    &Angle::default()
));
assert!(!rounded_rectangle.intersects_at(
    &circle,
    &[0.0, 2.4].into(),
    &Angle::default()
));
assert!(circle.intersects_at(
    &rounded_rectangle,
    &[0.0, 2.4].into(),
    &Angle::from(PI / 2.0)
));

Tuple Fields

0: S