pub struct Capsule<const N: usize> {
pub radius: PositiveReal,
pub height: PositiveReal,
}Expand description
All points less than or equal to a distance r from a line segment of length h.
This line is oriented along the [0 0 ... 1] direction, and has extents +h/2,
-h/2 along that axis.
Examples
Construction and basic methods:
use approxim::assert_relative_eq;
use hoomd_geometry::{BoundingSphereRadius, Volume, shape::Capsule};
use hoomd_vector::Cartesian;
use std::f64::consts::PI;
let capsule = Capsule::<2> {
radius: 1.0.try_into()?,
height: 8.0.try_into()?,
};
let bounding_radius = capsule.bounding_sphere_radius();
let volume = capsule.volume();
assert_eq!(bounding_radius.get(), 5.0);
assert_relative_eq!(volume, 16.0 + PI);Intersection test:
use hoomd_geometry::{Convex, IntersectsAt, shape::Capsule};
use hoomd_vector::{Angle, Cartesian, Rotation};
use std::f64::consts::PI;
let capsule = Capsule::<2> {
radius: 1.0.try_into()?,
height: 8.0.try_into()?,
};
assert!(capsule.intersects_at(
&capsule,
&[1.75, 0.0].into(),
&Angle::identity()
));
assert!(!capsule.intersects_at(
&capsule,
&[4.0, 2.0].into(),
&Angle::identity()
),);
assert!(capsule.intersects_at(
&capsule,
&[4.0, -2.0].into(),
&Angle::from(PI / 2.0)
));Fields
radius: PositiveRealRadius of points that are considered enclosed in the shape.
height: PositiveRealLength of the line segment.