pub struct HyperbolicConvexPolytope<const N: usize> { /* private fields */ }Expand description
A faceted hyperbolic solid defined by the convex hull of its vertices.
Examples
Construction and basic methods:
use hoomd_geometry::{
BoundingSphereRadius, shape::HyperbolicConvexPolytope,
};
let hyperbolic_square = HyperbolicConvexPolytope::<3>::regular(4, 0.5);
let bounding_radius = hyperbolic_square.bounding_sphere_radius();
assert_eq!(bounding_radius.get(), 0.5);Overlap check:
use hoomd_geometry::{IntersectsAtGlobal, shape::HyperbolicConvexPolytope};
use hoomd_manifold::Hyperbolic;
use hoomd_vector::Angle;
let square = HyperbolicConvexPolytope::<3>::regular(4, 0.5);
assert!(square.intersects_at_global(
&square,
&Hyperbolic::<3>::default(),
&Angle::default(),
&Hyperbolic::<3>::from_polar_coordinates(0.49, 2.3),
&Angle::from(0.4)
));
assert!(!square.intersects_at_global(
&square,
&Hyperbolic::<3>::default(),
&Angle::default(),
&Hyperbolic::<3>::from_polar_coordinates(3.0, 2.3),
&Angle::from(0.2)
));Implementations
Sourceimpl<const N: usize> HyperbolicConvexPolytope<N>
impl<const N: usize> HyperbolicConvexPolytope<N>
Sourcepub fn vertices(&self) -> &[Hyperbolic<N>]
pub fn vertices(&self) -> &[Hyperbolic<N>]
Get the vertices of the shape.
Sourceimpl HyperbolicConvexPolytope<3>
impl HyperbolicConvexPolytope<3>
Sourcepub fn regular(n: usize, circumradius: f64) -> HyperbolicConvexPolytope<3>
pub fn regular(n: usize, circumradius: f64) -> HyperbolicConvexPolytope<3>
Create a regular n-gon with n vertices and a given circumradius in hyperbolic space.
Sourcepub fn edge_distance(&self, phi: f64) -> f64
pub fn edge_distance(&self, phi: f64) -> f64
Calculate the distance between the center of a HyperbolicConvexPolytope<3>
centered at the origin and the edge at angle phi. The calculation works by
computing the intersection of the the hyperboloid with a plane passing
through the origin and the two adjacent vertices of the polygon.
Example
use approxim::assert_relative_eq;
use hoomd_geometry::shape::HyperbolicConvexPolytope;
use std::f64::consts::PI;
let bounding_radius = 0.5;
let hyperbolic_square =
HyperbolicConvexPolytope::<3>::regular(4, bounding_radius);
// calculation using hyperbolic trigonometry
let pi_fourths_distance =
(((PI / 4.0).cos()) * (bounding_radius.tanh())).atanh();
let edge_distance = hyperbolic_square.edge_distance(PI / 4.0);
assert_relative_eq!(pi_fourths_distance, edge_distance);Trait Implementations
Sourceimpl<const N: usize> BoundingSphereRadius for HyperbolicConvexPolytope<N>
impl<const N: usize> BoundingSphereRadius for HyperbolicConvexPolytope<N>
Sourcefn bounding_sphere_radius(&self) -> PositiveReal
fn bounding_sphere_radius(&self) -> PositiveReal
Get the bounding radius.
Sourceimpl<const N: usize> Clone for HyperbolicConvexPolytope<N>
impl<const N: usize> Clone for HyperbolicConvexPolytope<N>
Sourcefn clone(&self) -> HyperbolicConvexPolytope<N>
fn clone(&self) -> HyperbolicConvexPolytope<N>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<const N: usize> Debug for HyperbolicConvexPolytope<N>
impl<const N: usize> Debug for HyperbolicConvexPolytope<N>
Sourceimpl IntersectsAtGlobal<HyperbolicConvexPolytope<3>, Hyperbolic<3>, Angle> for HyperbolicConvexPolytope<3>
impl IntersectsAtGlobal<HyperbolicConvexPolytope<3>, Hyperbolic<3>, Angle> for HyperbolicConvexPolytope<3>
Sourcefn intersects_at_global(
&self,
other: &HyperbolicConvexPolytope<3>,
r_self: &Hyperbolic<3>,
o_self: &Angle,
r_other: &Hyperbolic<3>,
o_other: &Angle,
) -> bool
fn intersects_at_global( &self, other: &HyperbolicConvexPolytope<3>, r_self: &Hyperbolic<3>, o_self: &Angle, r_other: &Hyperbolic<3>, o_other: &Angle, ) -> bool
Test whether the set of points in one shape intersects with the set of another
(in the global frame). Read more
Sourceimpl<const N: usize> PartialEq for HyperbolicConvexPolytope<N>
impl<const N: usize> PartialEq for HyperbolicConvexPolytope<N>
impl<const N: usize> StructuralPartialEq for HyperbolicConvexPolytope<N>