pub type Spherocylinder = Capsule<3>;Expand description
A sphere swept along a line segment in $\mathbb{R}^3$.
Aliased Type
pub struct Spherocylinder {
pub radius: PositiveReal,
pub height: PositiveReal,
}Fields
radius: PositiveRealRadius of points that are considered enclosed in the shape.
height: PositiveRealLength of the line segment.